// *** VM1ATR1.cpp - Support library for VM1ATR1 board ***

#include "vm1atr1.h"

// ******************************
// Public functions
// ******************************
// Class constructor - Assign pins to I/O shift registers
VM1ATR1::VM1ATR1(){
	
	pinMode(SINPDATPIN, INPUT);		//Shift register data pin
	pinMode(SINPCLKPIN, OUTPUT);	//Shift clock pin	
	pinMode(SINPLATPIN, OUTPUT);	//Latch register pin
	pinMode(SOUTDATPIN, OUTPUT);	//Shift data pin
	pinMode(SOUTENBPIN, OUTPUT);	//Enable outputs pin
	pinMode(SOUTCLKPIN, OUTPUT);	//Shift clock pin
	pinMode(SOUTLATPIN, OUTPUT);	//Latch register pin
	dInpValue = 0;					//Clear digital input stored value_type	
	dOutValue = 0;					//Clear digital outputs stored value
}
// Read a single digital input
bool VM1ATR1::readDigitalInput(uint8_t index)	//Read a single digital input into a boolean variable
{
	if (index < 0) index = 0;
	if (index > 15) index = 15;
	dInpValue = readDigitalInputs();		//Get all 16 inputs
	return(bitRead(dInpValue, index));		//Return requested input
}
// Read all digital inputs
uint16_t VM1ATR1::readDigitalInputs(void)
{
	return(shiftIn16(SINPDATPIN, SINPCLKPIN, SINPLATPIN));	//Read raw digital inputs
}
// Write a single digital output
void VM1ATR1::writeDigitalOutput(uint8_t index, bool value)
{
	bitWrite(dOutValue, index, value);
	writeDigitalOutputs(dOutValue);
}
// Write all digital outputs
void VM1ATR1::writeDigitalOutputs(uint8_t value)
{
	dOutValue = value;							//Save value for read back
	digitalWrite(SOUTENBPIN,LOW);               //Enable Shiftout outputs
	digitalWrite(SOUTLATPIN, LOW);              //Latch outputts
	shiftOut8(SOUTDATPIN, SOUTCLKPIN, value);   //Update value
	digitalWrite(SOUTLATPIN, HIGH);             //Unlatch outputs
}
//Read back a single digital output
bool VM1ATR1::readDigitalOutput(uint8_t index)				//Read back a single digital outputs
{
	return(bitRead(dOutValue, index));
}
//Read back all 7 digital outputs
uint8_t VM1ATR1::readDigitalOutputs(uint8_t value)			//Read back all 7 digital outputs
{
	return(dOutValue);
}
// Read analog input - single sample
int VM1ATR1::readAnalogInput(uint8_t channel)
{
	if (channel < 0) channel = 0;
	if (channel > 5) channel = 5;
	return(analogRead(channel + AINP0));
}
// Read analog input - multiple samples with averaging
int VM1ATR1::readAnalogInput(uint8_t channel, uint8_t samples)
{
	int i;
	anaAvgValue[channel] = 0;	//Clear accumulator
	for (i = 0; i < samples; i++)
	{
		anaAvgValue[channel] += readAnalogInput(channel);
	}
	//The next line produces a compilation error - ?????
	//anaAvgValue[channel] = (readAnalogInput(channel) + anaAvgValue[channel] * (samples - 1)) / samples;
	return((int)(anaAvgValue[channel] / samples));
}
// Write analog output
void VM1ATR1::writeAnalogOutput(uint8_t channel, uint8_t value)
{
		if (channel < 0) channel = 0;
		if (channel > 1) channel = 1;
		analogWrite(AOUT0 + channel, constrain(value, 0, 255));
}
// ******************************
//Private functions
// ******************************
// Read all 16 digital inputs into 
uint16_t VM1ATR1::shiftIn16(uint8_t dataPin, uint8_t clockPin, uint8_t latchPin) {

  int i;
  uint16_t inputData = 0;
  uint16_t bitMask = 1;     //Initial input mask

  digitalWrite(latchPin, HIGH);	//Latch input register data
  delayMicroseconds(20);
  digitalWrite(latchPin, LOW);

  for (i=0; i<=15; i++) //Loop through all bits
  {
	if (digitalRead(dataPin)) inputData = inputData | bitMask ; //Read bit into result
	bitMask = bitMask << 1;
	//if (digitalRead(dataPin)) bitSet(inputData, i);
	//Create pulse to advance shift register
	digitalWrite(clockPin, 0);
	delayMicroseconds(1);
	digitalWrite(clockPin, 1);
  }
  //printf("Dinp:%u\n",inputData);
  return inputData;
}
void VM1ATR1::shiftOut8(uint8_t dataPin, uint8_t clockPin, byte val)
{
      int i;
      for (i = 0; i < 8; i++)  {
            digitalWrite(dataPin, !!(val & (1 << (7 - i))));	//Update output value
			//Create pulse to advance shift register
            digitalWrite(clockPin, HIGH);
            digitalWrite(clockPin, LOW);
      }
	  //printf("Dout:%d\n",val);
}

VM1ATR1 vm;	//Create instance