#ifndef _VM1ATR1_H
#define _VM1ATR1_H
// *** VM1ATR1.h - Support library for VM1ATR1 board ***
#include <Arduino.h>

// Hardware constants - Cannot be modified 
// Digital input shift-in register pins
#define SINPDATPIN 2	//D2 - Shift register data pin
#define SINPCLKPIN 3	//D3 - Shift clock pin
#define SINPLATPIN 4	//D4 - Latch register pin
// Digital outputs shift-out  register pins
#define SOUTDATPIN 10	//D10 - Shift data pin
#define SOUTENBPIN 11	//D11 - Enable outputs pin
#define SOUTCLKPIN 13	//D13 - Shift clock pin
#define SOUTLATPIN 12	//D12 - Latch register pin
// Analog inputs
#define AINP0 A0		//D14 - Analogue input 0 - J3 (4)
#define AINP1 A1		//D15 - Analogue input 1 - J3 (3)
#define AINP2 A2		//D16 - Analogue input 2 - J3 (2)
#define AINP3 A3		//D17 - Analogue input 3 - J3 (1)
#define AINP4 A4		//D18 - Analogue input 4 - (Also SDA pin for I2C interface)
#define AINP5 A5		//D19 - Analogue input 5 - (Also SCL pin for I2C interface)
//I2C lines
#define I2C_SDA A4		//Data (not used)
#define I2C_SCL A5		//Clock (not used)
//Analog outputs
#define AOUT0 11		//D11 - J1(1)
#define AOUT2 12		//D12 - J1(2)

class VM1ATR1
{
public:
	VM1ATR1();
	bool readDigitalInput(uint8_t index);				//Read a single digital input
	uint16_t readDigitalInputs(void);					//Read all 16 digital inputs
	void writeDigitalOutput(uint8_t index, bool value);	//Write a single digital output
	void writeDigitalOutputs(uint8_t value);			//Write all 7 digital outputs
	bool readDigitalOutput(uint8_t index);				//Read back a single digital output
	uint8_t readDigitalOutputs(uint8_t value);			//Read back all 7 digital outputs
	int readAnalogInput(uint8_t channel);					//Read one analogue input
	int readAnalogInput(uint8_t channel, uint8_t samples);	//Read one analogue input with averaging
	void writeAnalogOutput(uint8_t pin, uint8_t value);		//Write one analogue output 
private:
	uint16_t shiftIn16(uint8_t dataPin, uint8_t clockPin, uint8_t latchPin);
	void shiftOut8(uint8_t dataPin, uint8_t clockPin, byte val);
	uint16_t dInpValue;
	uint8_t dOutValue;
	long anaAvgValue[6];
};
extern VM1ATR1 vm;
#endif