#ifndef _MBTABLE_ENUM_H
#define _MBTABLE_ENUM_H
//
//	**** MODBUS DATA TABLE ENUMERATIONS ***
//
//	Use enumerations to assign easy to remember tags to your modbus variables.	
//	In this example the names chosen are generic (and quite bland too), so change
//	them to suit your application.
//
//	Usually the enumeration tables are placed in separate include files to simplify
//  its creation and maintenance across modbus Server and Client applications.
//
// 	In most applications I/O values are mapped into the modbus data table but this is not 
//	a requirement. You may map only those variables that have to be read or written
//	from the remote application (Modbus Client).
//
//	The application must take care of reading the physical inputs and set the values into 
//	the tables as well as transfer values from the table into physical outputs.
//
//  This example maps all I/O plus some internal variables to the modbus data table.
//	Prefixes X, Q and B are used to identify each boolean as an input, output or memory value
//	Prefixes I, O and D are used to identify each analog input, output or memory value.
//
enum boo_tags
{
	X_DINP00,	//Physical Digital input  00 - TB1 (2)
	X_DINP01,	//    "       "      "    01 - TB1 (3)
	X_DINP02,	//    "       "      "    02 - TB1 (4)
	X_DINP03,	//    "       "      "    03 - TB1 (5)
	X_DINP04,	//    "       "      "    04 - TB1 (6)
	X_DINP05,	//    "       "      "    05 - TB1 (7)
	X_DINP06,	//    "       "      "    06 - TB1 (8)
	X_DINP07,	//    "       "      "    07 - TB1 (9)
	X_DINP08,	//    "       "      "    08 - TB2 (1)
	X_DINP09,	//    "       "      "    09 - TB2 (2)
	X_DINP10,	//    "       "      "    10 - TB3 (3)
	X_DINP11,	//    "       "      "    11 - TB4 (4)
	X_DINP12,	//    "       "      "    12 - TB5 (5)
	X_DINP13,	//    "       "      "    13 - TB6 (6)
	X_DINP14,	//    "       "      "    14 - TB7 (7)
	X_DINP15,	//    "       "      "    15 - TB8 (8)
	Q_COIL00,	//Physical Digital output 00 - TB5 (2)
	Q_COIL01,	//    "       "      "    01 - TB5 (3)
	Q_COIL02,	//    "       "      "    02 - TB5 (4)
	Q_COIL03,	//    "       "      "    03 - TB5 (5)
	Q_AINPLO,	//    "       "      "    04 - TB5 (6)
	Q_AINPOK,	//    "       "      "    05 - TB5 (7)
	Q_AINPHI,	//    "       "      "    06 - TB5 (8)
	Q_DUMMYV,	//Not available (Do not use)
	B_TAG000,	//Memory boolean...
	B_TAG001,
	B_TAG002,
	B_TAG003,
	B_TAG004,
	B_TAG005,
	B_TAG006,
	B_TAGABC,
	B_TAGDEF,
	B_TAGGHI,
	// etc.. up to booTblLen - 1
};
enum ana_tags
{
	I_AINP00,	//D14 - Analog input 0 - J3 (4)
	I_AINP01,	//D15 - Analog input 1 - J3 (3)
	I_AINP02,	//D16 - Analog input 2 - J3 (2)
	I_AINP03,	//D17 - Analog input 3 - J3 (1)
	I_AINP04,	//D18 - Analog input 4 - (Also SDA pin for I2C interface)
	I_AINP05,	//D19 - Analog input 5 - (Also SCL pin for I2C interface)
	O_AOUT00,	//Analog PWM output value to J1 (1) 
	O_AOUT01,	//   "     "   "     "       J1 (2)
	D_HREG00,	//Memory value ...
	D_HREG05,
	D_MYTAGX,
	D_PX3AFC,
	D_T010LO,	//10 ms task event counter - LO word
	D_T010HI,	//10 ms task event counter - HI word
 	D_T100LO,	//100 ms task event counter - LO word
	D_T100HI,	//100 ms task event counter - HI word
	//etc.. up to anaTblLen - 1
};
#endif